@@ -138,6 +138,17 @@ na.omit.reflector_spct <- function(object, na.action = "omit", fill = NULL, ...)
                        target.colnames = "Rfr")
 }
 
+#' @rdname na.omit
+#'
+#' @export
+#'
+na.omit.object_spct <- function(object, na.action = "omit", fill = NULL, ...) {
+  na.omit.generic_spct(object = object,
+                       na.action = na.action,
+                       fill = fill,
+                       target.colnames = c("Trf", "Rfr"))
+}
+
 #' @rdname na.omit
 #'
 #' @export
@@ -228,6 +239,17 @@ na.exclude.reflector_spct <- function(object, na.action = "exclude", fill = NULL
                        target.colnames = "Rfr")
 }
 
+#' @rdname na.omit
+#'
+#' @export
+#'
+na.exclude.object_spct <- function(object, na.action = "exclude", fill = NULL, ...) {
+  na.omit.generic_spct(object = object,
+                       na.action = na.action,
+                       fill = fill,
+                       target.colnames = c("Trf", "Rfr"))
+}
+
 #' @rdname na.omit
 #'
 #' @export
